#pragma once

#include <adwaita.h>

G_BEGIN_DECLS

#define ADW_TYPE_DEMO_PAGE_ALERTS (adw_demo_page_alerts_get_type())

G_DECLARE_FINAL_TYPE (AdwDemoPageAlerts, adw_demo_page_alerts, ADW, DEMO_PAGE_ALERTS, AdwBin)

G_END_DECLS
